@@ -3,12 +3,10 @@
 
 var packageName = 'momentjs:moment';  // https://atmospherejs.com/momentjs/moment
 
-var packageJson = JSON.parse(Npm.require("fs").readFileSync('package.json'));
-
 Package.describe({
   name: packageName,
   summary: 'Moment.js (official): parse, validate, manipulate, and display dates - official Meteor packaging',
-  version: packageJson.version,
+  version: '2.16.0',
   git: 'https://github.com/moment/moment.git'
 });
 
@@ -17,7 +15,7 @@ Package.onUse(function (api) {
   api.export('moment');
   api.addFiles([
     'moment.js',
-    'meteor/export.js'
+    'export.js'
   ]);
 });
 
@@ -25,5 +23,5 @@ Package.onTest(function (api) {
   api.use(packageName);
   api.use('tinytest');
 
-  api.addFiles('meteor/test.js');
+  api.addFiles('test.js');
 });
